==> web-remote-control-1.5.0.tgz: package/www/WebServer.js <==
/*********************************************************************
 *                                                                   *
 *   Copyright 2016 Simon M. Werner                                  *
 *                                                                   *
 *   Licensed to the Apache Software Foundation (ASF) under one      *
 *   or more contributor license agreements.  See the NOTICE file    *
 *   distributed with this work for additional information           *
 *   regarding copyright ownership.  The ASF licenses this file      *
 *   to you under the Apache License, Version 2.0 (the               *
 *   'License'); you may not use this file except in compliance      *
 *   with the License.  You may obtain a copy of the License at      *
 *                                                                   *
 *      http://www.apache.org/licenses/LICENSE-2.0                   *
 *                                                                   *
 *   Unless required by applicable law or agreed to in writing,      *
 *   software distributed under the License is distributed on an     *
 *   'AS IS' BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY          *
 *   KIND, either express or implied.  See the License for the       *
 *   specific language governing permissions and limitations         *
 *   under the License.                                              *
 *                                                                   *
 *********************************************************************/

'use strict';


var stat = require('node-static');

var fileServer = new stat.Server('../www');

require('http').createServer(function (request, response) {
    request.addListener('end', function () {
        fileServer.serve(request, response)
                  .addListener('error', function (err) {
                        console.error('Error serving ' + request.url + ' - ' + err.message);
                  })
                  .addListener('success', function (obj) {
                        console.error(request.url + ' (' + obj.status + ')', obj.headers.Date);
                  });
    }).resume();
}).listen(8888);

==> web-remote-control-1.7.5.tgz: package/www/WebServer.js <==
/*********************************************************************
 *                                                                   *
 *   Copyright 2016 Simon M. Werner                                  *
 *                                                                   *
 *   Licensed to the Apache Software Foundation (ASF) under one      *
 *   or more contributor license agreements.  See the NOTICE file    *
 *   distributed with this work for additional information           *
 *   regarding copyright ownership.  The ASF licenses this file      *
 *   to you under the Apache License, Version 2.0 (the               *
 *   'License'); you may not use this file except in compliance      *
 *   with the License.  You may obtain a copy of the License at      *
 *                                                                   *
 *      http://www.apache.org/licenses/LICENSE-2.0                   *
 *                                                                   *
 *   Unless required by applicable law or agreed to in writing,      *
 *   software distributed under the License is distributed on an     *
 *   'AS IS' BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY          *
 *   KIND, either express or implied.  See the License for the       *
 *   specific language governing permissions and limitations         *
 *   under the License.                                              *
 *                                                                   *
 *********************************************************************/

'use strict';


var stat = require('node-static');

var fileServer = new stat.Server('./public');

var port = 8888;

require('http').createServer(function (request, response) {
    request.addListener('end', function () {
        //
        // Serve files!
        //
        fileServer.serve(request, response)
                  .addListener('error', function (err) {
                          console.error('Error serving ' + request.url + ' - ' + err.message);
                  })
                  .addListener('success', function (obj) {
                          console.error(request.url + ' (' + obj.status + ')', obj.headers.Date);
                  });
    }).resume();

}).listen(port);

console.log('Webserver listening on port: ', port);
